pub enum GradingProgress {
Failed,
NotReady,
PendingManual,
Pending,
FullyGraded,
}Expand description
How far along a task submission’s grading is.
Variants
Failed
The grading could not complete.
NotReady
No grading has occurred yet, e.g. the student has made no submission.
PendingManual
Final grade pending, needs human intervention. score_given, if present, is partial and may still change.
Pending
Final grade pending, no human intervention needed. score_given, if present, is partial and may still change.
FullyGraded
Grading is complete. score_given, if present, is the final grade.